@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Common Public License.
 //
-// $Id: cpp_example.cpp 1590 2009-10-28 00:44:42Z andreasw $
+// $Id: cpp_example.cpp 1692 2010-06-21 19:10:07Z andreasw $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-11-05
 
@@ -10,6 +10,17 @@
 #include "IpSolveStatistics.hpp"
 #include "MyNLP.hpp"
 
+// for printf
+#ifdef HAVE_CSTDIO
+# include <cstdio>
+#else
+# ifdef HAVE_STDIO_H
+#  include <stdio.h>
+# else
+#  error "don't have header file for stdio"
+# endif
+#endif
+
 using namespace Ipopt;
 
 int main(int argv, char* argc[])
