@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Common Public License.
 //
-// $Id: IpTSymLinearSolver.cpp 1019 2007-06-24 03:52:34Z andreasw $
+// $Id: IpTSymLinearSolver.cpp 1692 2010-06-21 19:10:07Z andreasw $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-03-17
 
@@ -105,6 +105,14 @@ namespace Ipopt
       case SparseSymLinearSolverInterface::CSR_Format_1_Offset:
         triplet_to_csr_converter_ = new TripletToCSRConverter(1);
         break;
+      case SparseSymLinearSolverInterface::CSR_Full_Format_0_Offset:
+        triplet_to_csr_converter_ = new TripletToCSRConverter(0,
+                                    TripletToCSRConverter::Full_Format);
+        break;
+      case SparseSymLinearSolverInterface::CSR_Full_Format_1_Offset:
+        triplet_to_csr_converter_ = new TripletToCSRConverter(1,
+                                    TripletToCSRConverter::Full_Format);
+        break;
       case SparseSymLinearSolverInterface::Triplet_Format:
         triplet_to_csr_converter_ = NULL;
         break;
